Crate nitro_shared

Crate nitro_shared 

This crate contains shared data for the other Nitrolaunch crates

Features:

  • schema: Enable generation of JSON schemas using the schemars crate

Modules

id
Types and structs for IDs of and references to things
io
Filesystem
java_args
Operating Java memory arguments
lang
Tools for languages and language detection
later
The Later enum
loaders
Enums for modifications to the game
minecraft
Common Mojang / Microsoft API types
nitro_executable
Finding viable Nitrolaunch executables for launching instances
output
Nitrolaunch output
pkg
Common package constructs
util
Other utilities
uuid
Tools for working with UUIDs
versions
Tools for dealing with version patterns

Macros

no_window
Prevents a command from spawning a window on Windows
skip_fail
Skip in a loop if a result fails
skip_none
Skip in a loop if an option is none
translate
Utility macro to translate from output
try_3
Macro to try a fallible operation multiple times before giving up and returning an error

Enums

Side
Minecraft game side, client or server
UpdateDepth
How deeply to update