pub enum AddonKind {
ResourcePack,
Mod,
Plugin,
Shader,
Datapack,
}Expand description
Different kinds of addons
Variants
ResourcePack
A Minecraft resource pack
Mod
A game modification that needs to be loaded by a custom loader
Plugin
A server plugin that modifies game behavior
Shader
A graphics shader that needs to be loaded by a shader modification
Datapack
A Minecraft datapack
Implementations
Sourceimpl AddonKind
impl AddonKind
Sourcepub fn parse_from_str(string: &str) -> Option<Self>
pub fn parse_from_str(string: &str) -> Option<Self>
Parse an AddonKind from a string
Sourcepub fn to_plural_string(&self) -> String
pub fn to_plural_string(&self) -> String
Plural version of to_string
Sourcepub fn get_extension(&self) -> &str
pub fn get_extension(&self) -> &str
Gets the file extension for this addon kind