get_terminal_width

Function get_terminal_width 

pub fn get_terminal_width(text: &str) -> usize
Calculate how many characters long something will appear to be in the terminal, skipping over escape sequences and the such