pub struct ReplPrinter { /* private fields */ }Expand description
Used to print text that is replaced
Implementations
Sourceimpl ReplPrinter
impl ReplPrinter
Sourcepub fn new(verbose: bool) -> Self
pub fn new(verbose: bool) -> Self
Make a new ReplPrinter with a verbosity option. If that option is false, then nothing will be printed
Sourcepub fn from_options(options: PrintOptions) -> Self
pub fn from_options(options: PrintOptions) -> Self
Make a new ReplPrinter using a set of print options
Sourcepub fn force_finished(&mut self)
pub fn force_finished(&mut self)
Force this printer to not make a newline when it finishes